@@ -8,11 +8,11 @@ from .Server import *
 
 
 class FlaskContextCreator(IQRContextCreator):
-    def create_context(self, request, rep: IQRRepository) -> QRContext:
+    def create_context(self, request, rep: IQRRepository, meta: dict) -> QRContext:
         json = request.get_json(silent=True)
         if json is None:
             json = dict()
-        return QRContext(json, request.args, request.headers, request.form, request.files, rep)
+        return QRContext(json, request.args, request.headers, request.form, request.files, rep, meta)
 
 
 class FlaskServer(IQRServer, FlaskContextCreator, QRLogger):
@@ -23,6 +23,7 @@ class FlaskServer(IQRServer, FlaskContextCreator, QRLogger):
         self.debug = None
         self.methods = {}
         self.managers = dict()
+        self.meta = dict()
 
         self.default_err_code = default_err_code
         self.default_err_msg = default_err_msg
@@ -52,7 +53,7 @@ class FlaskServer(IQRServer, FlaskContextCreator, QRLogger):
             self.app.route(route, methods=[method_type])(func)
 
     def __method(self, f, *args, **kwargs):
-        ctx = super().create_context(request, self)
+        ctx = super().create_context(request, self, meta=self.meta)
         ctx.set_managers(self.managers)
         in_msg = '[' + request.method + '] ' + request.url + '/' + request.query_string.decode()
         try:
@@ -61,12 +62,12 @@ class FlaskServer(IQRServer, FlaskContextCreator, QRLogger):
             end = time.time()
             msecs = int((end - start) * 1000)
             super().info('[' + str(msecs) + ' msecs]' + in_msg)
-            if result.raw_data:
-                return result.result
-            if result.status_code == 200:
-                return jsonify(result.result)
 
-            resp = Response(result.result, result.status_code)
+            if result.raw_data:
+                resp = Response(result.result, result.status_code)
+            else:
+                resp = jsonify(result.result)
+                resp.status_code = result.status_code
 
             if result.headers is not None:
                 for header, value in result.headers.items():
@@ -80,3 +81,6 @@ class FlaskServer(IQRServer, FlaskContextCreator, QRLogger):
 
     def register_manager(self, manager: IQRManager):
         self.managers[manager.get_name()] = manager
+
+    def set_meta(self, meta: dict):
+        self.meta = meta
\ No newline at end of file
