@@ -16,7 +16,7 @@ class QRContext:
     """object representing the request context, providing wrap around request's body and headers
     as well as repository instance and other possible managers"""
 
-    def __init__(self, json_data, params, headers, form, files, repository: IQRRepository):
+    def __init__(self, json_data, params, headers, form, files, repository: IQRRepository, meta=None):
         self.__json_data = json_data
         self.__params = params
         self.__headers = headers
@@ -25,6 +25,10 @@ class QRContext:
         self.__files = files
         self.managers = dict()
 
+        if meta is None:
+            meta = dict()
+        self.meta = meta
+
     def get_json_data(self): return self.__json_data
 
     def get_params(self): return self.__params
